:description: Building interactive UX in django using HTMX

Interactive user interfaces
===========================

.. warning::

    Work in progress. To receive updates `subscribe to this discussion <https://github.com/Tobi-De/falco/discussions/39>`_ or
    follow me on `x <https://twitter.com/tobidegnon>`_ or `mastodon <https://fosstodon.org/@tobide>`_.

.. In case you are not aware of it, htmx the new old hot stuff in web development, and pair really well with django.

Ressources and patterns
-----------------------


https://github.com/spookylukey/django-htmx-patterns
https://github.com/PyHAT-stack/awesome-python-htmx

Basic django htmx example
-------------------------


The HTMX javascript API
-----------------------


Others javascript library that works well with htmx
---------------------------------------------------



Alternatives to htmx
--------------------

Web components
--------------

use them first, If they feel easy enought to use, look out for way of building your own
